@@ -153,4 +153,25 @@ class RDSClient():
         """
         """
         query = f"SELECT * FROM neuralplatform_page WHERE id = {page_id};"
-        return self.select_query(query, fetchone=True)
\ No newline at end of file
+        return self.select_query(query, fetchone=True)
+    
+    def get_preprocessed_pages(self,
+                               document_ids: list):
+        """
+        """
+        classes = []
+        img_uris = []
+        ocr_uris = []
+        for document_id in document_ids:
+            query = f"SELECT tagged FROM neuralplatform_document WHERE id = {document_id};"
+            if self.select_query(query, fetchone=True)['tagged']:
+                query = f"SELECT classDefinition_id FROM neuralplatform_classification WHERE document_id = {document_id};"
+                class_id = self.select_query(query, fetchone=True)['class_id']
+                query = f"SELECT * FROM neuralplatform_page WHERE document_id = {document_id};"
+                pages = self.select_query(query)
+                for page in pages:
+                    if page['ocrUri'] and page['imgUri']:
+                        classes.append(class_id)
+                        img_uris.append(page['imgUri'])
+                        ocr_uris.append(page['ocrUri'])
+        return classes, img_uris, ocr_uris
