@@ -91,4 +91,13 @@ class S3Client(Boto3Client):
         """
         self.put_object(Body=json.dumps(word2idx).encode(), Bucket=bucket, Key=f"{project_name}/config/word2idx.json")
     
-    
\ No newline at end of file
+    def upload_model(self,
+                     bucket: str,
+                     project_name: str,
+                     version_id: int,
+                     model_name: int,
+                     model_path: str):
+        """
+        """
+        extension = model_path.split('.')[-1]
+        self.upload_file(model_path, bucket, f"{project_name}/versions/{version_id}/{model_name}/model.{extension}")
